@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 import sys
-from calculate.lib.utils.common import _error
+from calculate.lib.cl_template import TemplateFormat
 from calculate.lib.cl_lang import setLocalTranslate
 from collections import OrderedDict
 
@@ -23,7 +23,7 @@ _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 
-class kernel(_error):
+class kernel(TemplateFormat):
     """Класс для объединения файлов конфигурации ядра"""
     # root нода
     rootNode = False
@@ -36,8 +36,7 @@ class kernel(_error):
     # Комментарий
     _comment = "#"
 
-    def __init__(self, text):
-        self.text = text
+    def prepare(self):
         # Создаем пустой объект
         self.docObj = type("_empty_class", (object,), {})()
         # Названия аттрибутов для пустого объекта
